@@ -25,6 +25,8 @@
 Product Views
 """
 
+from __future__ import unicode_literals
+
 import os
 
 from sqlalchemy import and_
@@ -326,7 +328,7 @@ def print_labels(request):
         return {'error': "Quantity must be numeric"}
     quantity = int(quantity)
 
-    printer = profile.get_printer()
+    printer = profile.get_printer(request.rattail_config)
     if not printer:
         return {'error': "Couldn't get printer from label profile"}
 
